@@ -1,5 +1,6 @@
 from tsdoc0.python.model import Model
 from tsdoc0.python.segment import Segment
+from tsdoc0.python.utils import repr_parent
 from typing import Final
 from typing import Optional
 
@@ -8,7 +9,7 @@ import attr
 
 @attr.s(auto_attribs=True, kw_only=True)
 class SolutionCode(Segment):
-    parent: Optional[Model] = attr.ib(eq=False)
+    parent: Optional[Model] = attr.ib(eq=False, repr=repr_parent)
     indentation: Final[str]  # type: ignore[misc]
     text: Final[str]  # type: ignore[misc]
 
