@@ -47,6 +47,7 @@ class VocabularyTerm(Segment):
             "Character": "A single letter, number, punctuation mark, or symbol represented as a string",  # noqa: E501
             "Class": "A blueprint for creating something specific",
             "Collection": "A grouping of information",
+            "Collection unpacking": "Assigning the elements of a collection to individual variables in a single statement",  # noqa: E501
             "Collision": "When sprites touch or overlap",
             "Comment": "A note that the computer ignores",
             "Comparison operator": "Compares two values and gives a yes or no answer",
@@ -149,6 +150,7 @@ class VocabularyTerm(Segment):
             "Text": "An on-screen graphic based on a string",
             "Then block": "A section of code that might get run",
             "tsapp library": "A library used to create programs with graphics",
+            "Tuple": "An unchangeable collection of ordered elements",
             "Typecast": "Treat one data type like another",
             "User input": "Information the program receives from the user",
             "Variable": "A storage container for information",
@@ -177,6 +179,7 @@ class VocabularyTerm(Segment):
             "Character": "4.4.1",
             "Class": "3.3.1",
             "Collection": "4.1.1",
+            "Collection unpacking": "5.1.2",
             "Collision": "3.6.2",
             "Comment": "1.1.2",
             "Comparison operator": "2.1.2",
@@ -279,6 +282,7 @@ class VocabularyTerm(Segment):
             "Text": "3.4.2",
             "Then block": "2.2.1",
             "tsapp library": "3.4.1",
+            "Tuple": "5.1.1",
             "Typecast": "1.3.2",
             "User input": "1.1.3",
             "Variable": "1.1.3",
